@@ -461,6 +461,12 @@ class AtlasClient:
             job_id = response.json()['job_id']
 
         elif project['modality'] == 'text':
+            if indexed_field is None:
+                raise Exception("You did not specify a field to index. Specify an 'indexed_field'.")
+
+            if indexed_field not in project['project_fields']:
+                raise Exception(f"Your index field is not valid. Valid options are: {project['project_fields']}")
+
             hyperparameters = {
                 'dataset_buffer_size': 1000,
                 'batch_size': 4,
@@ -478,7 +484,7 @@ class AtlasClient:
                 'nearest_neighbor_index_hyperparameters': json.dumps({'space': 'l2', 'ef_construction': 100, 'M': 16}),
                 'projection': 'NomicProject',
                 'projection_hyperparameters': json.dumps(
-                    {'n_neighbors': 15, 'min_dist': 3e-2, 'force_approximation_algorithm': True}
+                    {'n_neighbors': 15, 'n_epochs': 50, 'spread': 1}
                 ),
             }
             response = requests.post(
